#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_TWOTO31_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_TWOTO31_HPP_INCLUDED

#include <boost/simd/constant/include/constants/twoto31.hpp>

#endif
